==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1NodeAffinityFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1NodeAffinityFluent<A extends V1NodeAffinityFluent<A>> extends Fluent<A>{


    public A addToPreferredDuringSchedulingIgnoredDuringExecution(int index,V1PreferredSchedulingTerm item);
    public A setToPreferredDuringSchedulingIgnoredDuringExecution(int index,V1PreferredSchedulingTerm item);
    public A addToPreferredDuringSchedulingIgnoredDuringExecution(V1PreferredSchedulingTerm... items);
    public A addAllToPreferredDuringSchedulingIgnoredDuringExecution(Collection<V1PreferredSchedulingTerm> items);
    public A removeFromPreferredDuringSchedulingIgnoredDuringExecution(V1PreferredSchedulingTerm... items);
    public A removeAllFromPreferredDuringSchedulingIgnoredDuringExecution(Collection<V1PreferredSchedulingTerm> items);
    
/**
 * This method has been deprecated, please use method buildPreferredDuringSchedulingIgnoredDuringExecution instead.
 * @return The buildable object.
 */
@Deprecated public List<V1PreferredSchedulingTerm> getPreferredDuringSchedulingIgnoredDuringExecution();
    public List<V1PreferredSchedulingTerm> buildPreferredDuringSchedulingIgnoredDuringExecution();
    public V1PreferredSchedulingTerm buildPreferredDuringSchedulingIgnoredDuringExecution(int index);
    public V1PreferredSchedulingTerm buildFirstPreferredDuringSchedulingIgnoredDuringExecution();
    public V1PreferredSchedulingTerm buildLastPreferredDuringSchedulingIgnoredDuringExecution();
    public V1PreferredSchedulingTerm buildMatchingPreferredDuringSchedulingIgnoredDuringExecution(io.kubernetes.client.fluent.Predicate<V1PreferredSchedulingTermBuilder> predicate);
    public A withPreferredDuringSchedulingIgnoredDuringExecution(List<V1PreferredSchedulingTerm> preferredDuringSchedulingIgnoredDuringExecution);
    public A withPreferredDuringSchedulingIgnoredDuringExecution(V1PreferredSchedulingTerm... preferredDuringSchedulingIgnoredDuringExecution);
    public Boolean hasPreferredDuringSchedulingIgnoredDuringExecution();
    public V1NodeAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> addNewPreferredDuringSchedulingIgnoredDuringExecution();
    public V1NodeAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> addNewPreferredDuringSchedulingIgnoredDuringExecutionLike(V1PreferredSchedulingTerm item);
    public V1NodeAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> setNewPreferredDuringSchedulingIgnoredDuringExecutionLike(int index,V1PreferredSchedulingTerm item);
    public V1NodeAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> editPreferredDuringSchedulingIgnoredDuringExecution(int index);
    public V1NodeAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> editFirstPreferredDuringSchedulingIgnoredDuringExecution();
    public V1NodeAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> editLastPreferredDuringSchedulingIgnoredDuringExecution();
    public V1NodeAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> editMatchingPreferredDuringSchedulingIgnoredDuringExecution(io.kubernetes.client.fluent.Predicate<V1PreferredSchedulingTermBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildRequiredDuringSchedulingIgnoredDuringExecution instead.
 * @return The buildable object.
 */
@Deprecated public V1NodeSelector getRequiredDuringSchedulingIgnoredDuringExecution();
    public V1NodeSelector buildRequiredDuringSchedulingIgnoredDuringExecution();
    public A withRequiredDuringSchedulingIgnoredDuringExecution(V1NodeSelector requiredDuringSchedulingIgnoredDuringExecution);
    public Boolean hasRequiredDuringSchedulingIgnoredDuringExecution();
    public V1NodeAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> withNewRequiredDuringSchedulingIgnoredDuringExecution();
    public V1NodeAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> withNewRequiredDuringSchedulingIgnoredDuringExecutionLike(V1NodeSelector item);
    public V1NodeAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> editRequiredDuringSchedulingIgnoredDuringExecution();
    public V1NodeAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> editOrNewRequiredDuringSchedulingIgnoredDuringExecution();
    public V1NodeAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> editOrNewRequiredDuringSchedulingIgnoredDuringExecutionLike(V1NodeSelector item);

    public interface PreferredDuringSchedulingIgnoredDuringExecutionNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1PreferredSchedulingTermFluent<V1NodeAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<N>>{

        
    public N and();    public N endPreferredDuringSchedulingIgnoredDuringExecution();
}
    public interface RequiredDuringSchedulingIgnoredDuringExecutionNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1NodeSelectorFluent<V1NodeAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<N>>{

        
    public N and();    public N endRequiredDuringSchedulingIgnoredDuringExecution();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1NodeAffinityFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1NodeAffinityFluent<A extends V1NodeAffinityFluent<A>> extends Fluent<A>{


    public A addToPreferredDuringSchedulingIgnoredDuringExecution(int index,V1PreferredSchedulingTerm item);
    public A setToPreferredDuringSchedulingIgnoredDuringExecution(int index,V1PreferredSchedulingTerm item);
    public A addToPreferredDuringSchedulingIgnoredDuringExecution(V1PreferredSchedulingTerm... items);
    public A addAllToPreferredDuringSchedulingIgnoredDuringExecution(Collection<V1PreferredSchedulingTerm> items);
    public A removeFromPreferredDuringSchedulingIgnoredDuringExecution(V1PreferredSchedulingTerm... items);
    public A removeAllFromPreferredDuringSchedulingIgnoredDuringExecution(Collection<V1PreferredSchedulingTerm> items);
    
/**
 * This method has been deprecated, please use method buildPreferredDuringSchedulingIgnoredDuringExecution instead.
 * @return The buildable object.
 */
@Deprecated public List<V1PreferredSchedulingTerm> getPreferredDuringSchedulingIgnoredDuringExecution();
    public List<V1PreferredSchedulingTerm> buildPreferredDuringSchedulingIgnoredDuringExecution();
    public V1PreferredSchedulingTerm buildPreferredDuringSchedulingIgnoredDuringExecution(int index);
    public V1PreferredSchedulingTerm buildFirstPreferredDuringSchedulingIgnoredDuringExecution();
    public V1PreferredSchedulingTerm buildLastPreferredDuringSchedulingIgnoredDuringExecution();
    public V1PreferredSchedulingTerm buildMatchingPreferredDuringSchedulingIgnoredDuringExecution(io.kubernetes.client.fluent.Predicate<V1PreferredSchedulingTermBuilder> predicate);
    public Boolean hasMatchingPreferredDuringSchedulingIgnoredDuringExecution(io.kubernetes.client.fluent.Predicate<V1PreferredSchedulingTermBuilder> predicate);
    public A withPreferredDuringSchedulingIgnoredDuringExecution(List<V1PreferredSchedulingTerm> preferredDuringSchedulingIgnoredDuringExecution);
    public A withPreferredDuringSchedulingIgnoredDuringExecution(V1PreferredSchedulingTerm... preferredDuringSchedulingIgnoredDuringExecution);
    public Boolean hasPreferredDuringSchedulingIgnoredDuringExecution();
    public V1NodeAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> addNewPreferredDuringSchedulingIgnoredDuringExecution();
    public V1NodeAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> addNewPreferredDuringSchedulingIgnoredDuringExecutionLike(V1PreferredSchedulingTerm item);
    public V1NodeAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> setNewPreferredDuringSchedulingIgnoredDuringExecutionLike(int index,V1PreferredSchedulingTerm item);
    public V1NodeAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> editPreferredDuringSchedulingIgnoredDuringExecution(int index);
    public V1NodeAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> editFirstPreferredDuringSchedulingIgnoredDuringExecution();
    public V1NodeAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> editLastPreferredDuringSchedulingIgnoredDuringExecution();
    public V1NodeAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<A> editMatchingPreferredDuringSchedulingIgnoredDuringExecution(io.kubernetes.client.fluent.Predicate<V1PreferredSchedulingTermBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildRequiredDuringSchedulingIgnoredDuringExecution instead.
 * @return The buildable object.
 */
@Deprecated public V1NodeSelector getRequiredDuringSchedulingIgnoredDuringExecution();
    public V1NodeSelector buildRequiredDuringSchedulingIgnoredDuringExecution();
    public A withRequiredDuringSchedulingIgnoredDuringExecution(V1NodeSelector requiredDuringSchedulingIgnoredDuringExecution);
    public Boolean hasRequiredDuringSchedulingIgnoredDuringExecution();
    public V1NodeAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> withNewRequiredDuringSchedulingIgnoredDuringExecution();
    public V1NodeAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> withNewRequiredDuringSchedulingIgnoredDuringExecutionLike(V1NodeSelector item);
    public V1NodeAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> editRequiredDuringSchedulingIgnoredDuringExecution();
    public V1NodeAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> editOrNewRequiredDuringSchedulingIgnoredDuringExecution();
    public V1NodeAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<A> editOrNewRequiredDuringSchedulingIgnoredDuringExecutionLike(V1NodeSelector item);

    public interface PreferredDuringSchedulingIgnoredDuringExecutionNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1PreferredSchedulingTermFluent<V1NodeAffinityFluent.PreferredDuringSchedulingIgnoredDuringExecutionNested<N>>{

        
    public N and();    public N endPreferredDuringSchedulingIgnoredDuringExecution();
}
    public interface RequiredDuringSchedulingIgnoredDuringExecutionNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1NodeSelectorFluent<V1NodeAffinityFluent.RequiredDuringSchedulingIgnoredDuringExecutionNested<N>>{

        
    public N and();    public N endRequiredDuringSchedulingIgnoredDuringExecution();
}


}
